@@ -2,12 +2,10 @@
 
 from __future__ import with_statement
 import sys
-import os.path
 from pyke import knowledge_engine
 from pyke import krb_traceback
 
-engine = knowledge_engine.engine(os.path.dirname(__file__),
-                                 'examples.findall.compiled_krb')
+engine = knowledge_engine.engine('examples.findall')
 
 def fc_test():
     engine.reset()
