@@ -2,12 +2,10 @@
 
 from __future__ import with_statement
 import sys
-import os.path
 from pyke import knowledge_engine
 from pyke import krb_traceback
 
-engine = knowledge_engine.engine(os.path.dirname(__file__),
-                                 'examples.towers_of_hanoi.compiled_krb')
+engine = knowledge_engine.engine('examples.towers_of_hanoi')
 
 def test(num_disks):
     engine.reset()
