@@ -1,4 +1,4 @@
-# $Id: kfbparser.py 185 2009-03-06 19:02:16Z mtnyogi $
+# $Id: kfbparser.py 87e5bee9250a 2009-10-24 mtnyogi $
 # coding=utf-8
 # 
 # Copyright © 2008 Bruce Frederiksen
@@ -143,9 +143,8 @@ def parse(this_module, filename, check_tables = False, debug = 0):
     '''
         >>> from pyke.krb_compiler import kfbparser
         >>> kfbparser.parse(kfbparser,
-        ...                 'TEST/kfbparse_test.kfb'
-        ...                 if os.path.split(os.getcwd())[1] == 'krb_compiler'
-        ...                 else 'krb_compiler/TEST/kfbparse_test.kfb',
+        ...                 os.path.join(os.path.dirname(__file__),
+        ...                              'TEST/kfbparse_test.kfb'),
         ...                 True)
         <fact_base kfbparse_test>
     '''
